.. image:: https://img.shields.io/pypi/v/jaraco.services.svg
   :target: https://pypi.org/project/jaraco.services

.. image:: https://img.shields.io/pypi/pyversions/jaraco.services.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.services/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.services

.. image:: https://readthedocs.org/projects/jaracoservices/badge/?version=latest
   :target: https://jaracoservices.readthedocs.io/en/latest/?badge=latest

